@@ -9,28 +9,34 @@
 #' @param random A logical indicating whether results for the random
 #'   effects model should be printed.
 #' @param digits Minimal number of significant digits.
+#' @param nchar.trts A numeric defining the minimum number of
+#'   characters used to create unique treatment names (see Details).
+#' @param nchar.studlab A numeric defining the minimum number of
+#'   characters used to create unique study labels.
+#' @param details.methods A logical specifying whether details on statistical
+#'   methods should be printed.
 #' @param legend A logical indicating whether a legend should be
 #'   printed.
+#' @param legend.studlab A logical indicating whether a legend should
+#'   be printed for abbreviated study labels.
 #' @param warn.deprecated A logical indicating whether warnings should
 #'   be printed if deprecated arguments are used.
 #' @param \dots Additional arguments (to catch deprecated arguments).
 #' 
 #' @author Guido Schwarzer \email{guido.schwarzer@@uniklinik-freiburg.de}
 #' 
-#' @seealso \code{\link{netimpact}}
+#' @seealso \code{\link{netimpact}}, \code{\link[metadat]{dat.franchini2012}}
 #' 
 #' @keywords print
 #' 
 #' @examples
-#' data(Franchini2012)
-#'
 #' # Only consider first two studies (to reduce runtime of example)
 #' #
-#' studies <- unique(Franchini2012$Study)
+#' studies <- unique(dat.franchini2012$Study)
 #' p1 <- pairwise(list(Treatment1, Treatment2, Treatment3),
 #'   n = list(n1, n2, n3),
 #'   mean = list(y1, y2, y3), sd = list(sd1, sd2, sd3),
-#'   data = subset(Franchini2012, Study %in% studies[1:2]),
+#'   data = subset(dat.franchini2012, Study %in% studies[1:2]),
 #'   studlab = Study)
 #' 
 #' net1 <- netmeta(p1)
@@ -40,13 +46,18 @@
 #' @method print netimpact
 #' @export
 
-
 print.netimpact <- function(x,
                             common = x$x$common,
                             random = x$x$random,
+                            #
                             digits = gs("digits.prop"),
-                            ##
-                            legend = TRUE,
+                            #
+                            nchar.trts = x$nchar.trts,
+                            nchar.studlab = x$nchar.studlab,
+                            #
+                            details.methods = gs("details"),
+                            legend = gs("legend"),
+                            legend.studlab = TRUE,
                             warn.deprecated = gs("warn.deprecated"),
                             ##
                             ...) {
@@ -66,7 +77,9 @@ print.netimpact <- function(x,
   ##
   ##
   chknumeric(digits, min = 0, length = 1)
+  chklogical(details.methods)
   chklogical(legend)
+  chklogical(legend.studlab)
   ##
   ## Check for deprecated arguments in '...'
   ##
@@ -101,9 +114,9 @@ print.netimpact <- function(x,
   trts <- x$x$trts
   ##
   treat1 <- as.character(factor(treat1.long, levels = trts,
-                                labels = treats(trts, x$x$nchar.trts)))
+                                labels = treats(trts, nchar.trts)))
   treat2 <- as.character(factor(treat2.long, levels = trts,
-                                labels = treats(trts, x$x$nchar.trts)))
+                                labels = treats(trts, nchar.trts)))
   
   
   ##
@@ -114,6 +127,11 @@ print.netimpact <- function(x,
   if (common) {
     cat("Common effects model: \n\n")
     impact.common <- formatN(x$impact.common, digits = digits)
+    #
+    studlab <- rownames(impact.common)
+    studlab.abbr <- treats(studlab, nchar.studlab)
+    rownames(impact.common) <- studlab.abbr
+    #
     colnames(impact.common) <- paste(treat1, treat2, sep = sep.trts)
     ##
     prmatrix(impact.common, quote = FALSE, right = TRUE)
@@ -126,15 +144,31 @@ print.netimpact <- function(x,
   if (random) {
     cat("Random effects model: \n\n")
     impact.random <- formatN(x$impact.random, digits = digits)
+    #
+    studlab <- rownames(impact.random)
+    studlab.abbr <- treats(studlab, nchar.studlab)
+    rownames(impact.random) <- studlab.abbr
+    #
     colnames(impact.random) <- paste(treat1, treat2, sep = sep.trts)
     ##
     prmatrix(impact.random, quote = FALSE, right = TRUE)
   }
+  #
+  # Print details of network meta-analysis methods
+  #
+  if (details.methods & (common | random))
+    cat(textmeth(x, random))
   ##
   ## Add legend with abbreviated treatment labels
   ##
-  if (common | random)
-    legendabbr(trts, treats(trts, x$x$nchar.trts), legend)
+  if (legend & (common | random))
+    legendabbr(trts, treats(trts, nchar.trts), legend)
+  #
+  # Add legend with abbreviated study labels
+  #
+  if (legend.studlab & (common | random))
+    legendabbr(studlab, studlab.abbr, TRUE, "Study label",
+               if (legend) "\n" else "\nLegend:\n")
   
   
   invisible(NULL)
